@@ -14,6 +14,7 @@ import uuid
 from datetime import datetime
 from io import BytesIO
 from threading import BoundedSemaphore
+from typing import Dict, List
 
 from flask import Flask, Response, jsonify, request
 from six.moves import cStringIO as StringIO
@@ -134,12 +135,16 @@ CHECK_HANDLER_ON_CREATION = False
 
 
 class LambdaRegion(RegionBackend):
+    # map ARN strings to lambda function objects
+    lambdas: Dict[str, LambdaFunction]
+    # map ARN strings to CodeSigningConfig object
+    code_signing_configs: Dict[str, CodeSigningConfig]
+    # list of event source mappings for the API
+    event_source_mappings: List[Dict]
+
     def __init__(self):
-        # map ARN strings to lambda function objects
         self.lambdas = {}
-        # map ARN strings to CodeSigningConfig object
         self.code_signing_configs = {}
-        # list of event source mappings for the API
         self.event_source_mappings = []
 
 
@@ -226,7 +231,7 @@ def add_function_mapping(lambda_name, lambda_handler, lambda_cwd=None):
     lambda_details.cwd = lambda_cwd or lambda_details.cwd
 
 
-def build_mapping_obj(data):
+def build_mapping_obj(data) -> Dict:
     mapping = {}
     function_name = data["FunctionName"]
     enabled = data.get("Enabled", True)
@@ -310,7 +315,17 @@ def use_docker():
     if DO_USE_DOCKER is None:
         DO_USE_DOCKER = False
         if "docker" in config.LAMBDA_EXECUTOR:
-            DO_USE_DOCKER = DOCKER_CLIENT.has_docker()
+            has_docker = DOCKER_CLIENT.has_docker()
+            if not has_docker:
+                LOG.warning(
+                    (
+                        "Lambda executor configured as LAMBDA_EXECUTOR=%s but Docker "
+                        "is not accessible. Please make sure to mount the Docker socket "
+                        "/var/run/docker.sock into the container."
+                    )
+                    % config.LAMBDA_EXECUTOR
+                )
+            DO_USE_DOCKER = has_docker
     return DO_USE_DOCKER
 
 
@@ -2265,6 +2280,9 @@ def serve(port):
     # initialize the Lambda executor
     LAMBDA_EXECUTOR.startup()
 
+    # initialize/import plugins - TODO find better place to import plugins! (to be integrated into proper plugin model)
+    import localstack.plugin.thundra  # noqa
+
     generic_proxy.serve_flask_app(app=app, port=port)
 
 
@@ -2274,7 +2292,7 @@ def on_config_change(config_key: str, config_newvalue: str) -> None:
     if config_key != "LAMBDA_EXECUTOR":
         return
     LOG.debug(
-        "Recieved config event for lambda executor! Key: {} Value: {}".format(
+        "Received config event for lambda executor - Key: '{}', Value: {}".format(
             config_key, config_newvalue
         )
     )
