@@ -1630,8 +1630,10 @@ def serve_static_website(headers, path, bucket_name):
     try:
         if path != "/":
             path = path.lstrip("/")
-            content = s3_client.get_object(Bucket=bucket_name, Key=path)["Body"].read()
-            return requests_response(status_code=200, content=content)
+            obj = s3_client.get_object(Bucket=bucket_name, Key=path)
+            content = obj["Body"].read()
+            headers = {"Content-Type": obj["ContentType"]} if obj.get("ContentType") else {}
+            return requests_response(status_code=200, content=content, headers=headers)
     except ClientError:
         LOGGER.debug("No such key found. %s" % path)
 
