@@ -189,7 +189,13 @@ def get_boto3_session(cache=True):
 
 
 def get_region():
-    # TODO look up region from context
+    # Note: leave import here to avoid import errors (e.g., "flask") for CLI commands
+    from localstack.utils.aws.request_context import get_region_from_request_context
+
+    region = get_region_from_request_context()
+    if region:
+        return region
+    # fall back to returning static pre-defined region
     return get_local_region()
 
 
@@ -377,6 +383,11 @@ def check_valid_region(headers):
 
 
 def set_default_region_in_headers(headers, service=None, region=None):
+    # this should now be a no-op, as we support arbitrary regions and don't use a "default" region
+    # TODO: remove this function once the legacy USE_SINGLE_REGION config is removed
+    if not config.USE_SINGLE_REGION:
+        return
+
     auth_header = headers.get("Authorization")
     region = region or get_region()
     if not auth_header:
